aboutsummaryrefslogtreecommitdiff
path: root/internal/utils/progress.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/utils/progress.go')
-rw-r--r--internal/utils/progress.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/utils/progress.go b/internal/utils/progress.go
index acb763ac..2adcb26a 100644
--- a/internal/utils/progress.go
+++ b/internal/utils/progress.go
@@ -6,10 +6,10 @@ import (
"io"
)
// FprintfBestEffort writes one formatted message to w.
//
// It is nil-safe and ignores write errors by design.
-func FprintfBestEffort(w io.Writer, format string, args ...any) {
+func BestEffortFprintf(w io.Writer, format string, args ...any) {
if w == nil {
return
}
@@ -6,10 +6,10 @@ import (
"io"
)
-// FprintfBestEffort writes one formatted message to w.
+// BestEffortFprintf writes one formatted message to w.
//
// It is nil-safe and ignores write errors by design.